==> pigment_0.3.6.orig.tar.gz: pigment-0.3.6/pgm/pgmenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef __PGM_ENUM_TYPES_H__
#define __PGM_ENUM_TYPES_H__

G_BEGIN_DECLS

/* --- ./pgmcommon.h --- */
#define PGM_TYPE_ERROR pgm_error_get_type()
GType pgm_error_get_type (void);

/* --- ./pgmdrawable.h --- */
#define PGM_TYPE_DRAWABLE_LAYER pgm_drawable_layer_get_type()
GType pgm_drawable_layer_get_type (void);

#define PGM_TYPE_DRAWABLE_PROPERTY pgm_drawable_property_get_type()
GType pgm_drawable_property_get_type (void);

#define PGM_TYPE_DRAWABLE_FLAGS pgm_drawable_flags_get_type()
GType pgm_drawable_flags_get_type (void);

#define PGM_TYPE_DRAWABLE_PICKING_SIGNAL pgm_drawable_picking_signal_get_type()
GType pgm_drawable_picking_signal_get_type (void);

/* --- ./pgmevents.h --- */
#define PGM_TYPE_EVENT_TYPE pgm_event_type_get_type()
GType pgm_event_type_get_type (void);

#define PGM_TYPE_MODIFIER_TYPE pgm_modifier_type_get_type()
GType pgm_modifier_type_get_type (void);

#define PGM_TYPE_BUTTON_TYPE pgm_button_type_get_type()
GType pgm_button_type_get_type (void);

#define PGM_TYPE_SCROLL_DIRECTION pgm_scroll_direction_get_type()
GType pgm_scroll_direction_get_type (void);

/* --- ./pgmimage.h --- */
#define PGM_TYPE_IMAGE_ALIGNMENT pgm_image_alignment_get_type()
GType pgm_image_alignment_get_type (void);

#define PGM_TYPE_IMAGE_LAYOUT_TYPE pgm_image_layout_type_get_type()
GType pgm_image_layout_type_get_type (void);

#define PGM_TYPE_IMAGE_INTERP_TYPE pgm_image_interp_type_get_type()
GType pgm_image_interp_type_get_type (void);

#define PGM_TYPE_IMAGE_PIXEL_FORMAT pgm_image_pixel_format_get_type()
GType pgm_image_pixel_format_get_type (void);

#define PGM_TYPE_IMAGE_STORAGE_TYPE pgm_image_storage_type_get_type()
GType pgm_image_storage_type_get_type (void);

/* --- ./pgmtext.h --- */
#define PGM_TYPE_TEXT_ELLIPSIZE pgm_text_ellipsize_get_type()
GType pgm_text_ellipsize_get_type (void);

#define PGM_TYPE_TEXT_ALIGNMENT pgm_text_alignment_get_type()
GType pgm_text_alignment_get_type (void);

#define PGM_TYPE_TEXT_WRAP pgm_text_wrap_get_type()
GType pgm_text_wrap_get_type (void);

#define PGM_TYPE_TEXT_GRAVITY pgm_text_gravity_get_type()
GType pgm_text_gravity_get_type (void);

#define PGM_TYPE_TEXT_STRETCH pgm_text_stretch_get_type()
GType pgm_text_stretch_get_type (void);

#define PGM_TYPE_TEXT_STYLE pgm_text_style_get_type()
GType pgm_text_style_get_type (void);

#define PGM_TYPE_TEXT_VARIANT pgm_text_variant_get_type()
GType pgm_text_variant_get_type (void);

#define PGM_TYPE_TEXT_WEIGHT pgm_text_weight_get_type()
GType pgm_text_weight_get_type (void);

/* --- ./pgmviewport.h --- */
#define PGM_TYPE_VIEWPORT_CURSOR pgm_viewport_cursor_get_type()
GType pgm_viewport_cursor_get_type (void);

#define PGM_TYPE_VIEWPORT_CAPACITY pgm_viewport_capacity_get_type()
GType pgm_viewport_capacity_get_type (void);

#define PGM_TYPE_VIEWPORT_ROTATION pgm_viewport_rotation_get_type()
GType pgm_viewport_rotation_get_type (void);

#define PGM_TYPE_VIEWPORT_REFLECTION pgm_viewport_reflection_get_type()
GType pgm_viewport_reflection_get_type (void);

/* --- ./pgmlinearalgebra.h --- */
#define PGM_TYPE_MAT4X4_PREDEFINED pgm_mat4x4_predefined_get_type()
GType pgm_mat4x4_predefined_get_type (void);

/* --- ./pgmimagesink.h --- */
#define PGM_TYPE_IMAGE_SINK_EVENT_MASK pgm_image_sink_event_mask_get_type()
GType pgm_image_sink_event_mask_get_type (void);

G_END_DECLS

#endif

/* Generated data ends here */

==> pigment_0.3.8.orig.tar.gz: pigment-0.3.8/pgm/pgmenumtypes.h <==

/* Generated data (by glib-mkenums) */

#ifndef __PGM_ENUM_TYPES_H__
#define __PGM_ENUM_TYPES_H__

G_BEGIN_DECLS

/* --- ./pgmcommon.h --- */
#define PGM_TYPE_ERROR pgm_error_get_type()
GType pgm_error_get_type (void);

/* --- ./pgmdrawable.h --- */
#define PGM_TYPE_DRAWABLE_LAYER pgm_drawable_layer_get_type()
GType pgm_drawable_layer_get_type (void);

#define PGM_TYPE_DRAWABLE_PROPERTY pgm_drawable_property_get_type()
GType pgm_drawable_property_get_type (void);

#define PGM_TYPE_DRAWABLE_FLAGS pgm_drawable_flags_get_type()
GType pgm_drawable_flags_get_type (void);

#define PGM_TYPE_DRAWABLE_PICKING_SIGNAL pgm_drawable_picking_signal_get_type()
GType pgm_drawable_picking_signal_get_type (void);

/* --- ./pgmevents.h --- */
#define PGM_TYPE_EVENT_TYPE pgm_event_type_get_type()
GType pgm_event_type_get_type (void);

#define PGM_TYPE_MODIFIER_TYPE pgm_modifier_type_get_type()
GType pgm_modifier_type_get_type (void);

#define PGM_TYPE_BUTTON_TYPE pgm_button_type_get_type()
GType pgm_button_type_get_type (void);

#define PGM_TYPE_SCROLL_DIRECTION pgm_scroll_direction_get_type()
GType pgm_scroll_direction_get_type (void);

/* --- ./pgmimage.h --- */
#define PGM_TYPE_IMAGE_ALIGNMENT pgm_image_alignment_get_type()
GType pgm_image_alignment_get_type (void);

#define PGM_TYPE_IMAGE_LAYOUT_TYPE pgm_image_layout_type_get_type()
GType pgm_image_layout_type_get_type (void);

#define PGM_TYPE_IMAGE_INTERP_TYPE pgm_image_interp_type_get_type()
GType pgm_image_interp_type_get_type (void);

#define PGM_TYPE_IMAGE_WRAPPING pgm_image_wrapping_get_type()
GType pgm_image_wrapping_get_type (void);

#define PGM_TYPE_IMAGE_PIXEL_FORMAT pgm_image_pixel_format_get_type()
GType pgm_image_pixel_format_get_type (void);

#define PGM_TYPE_IMAGE_STORAGE_TYPE pgm_image_storage_type_get_type()
GType pgm_image_storage_type_get_type (void);

/* --- ./pgmtext.h --- */
#define PGM_TYPE_TEXT_ELLIPSIZE pgm_text_ellipsize_get_type()
GType pgm_text_ellipsize_get_type (void);

#define PGM_TYPE_TEXT_ALIGNMENT pgm_text_alignment_get_type()
GType pgm_text_alignment_get_type (void);

#define PGM_TYPE_TEXT_WRAP pgm_text_wrap_get_type()
GType pgm_text_wrap_get_type (void);

#define PGM_TYPE_TEXT_GRAVITY pgm_text_gravity_get_type()
GType pgm_text_gravity_get_type (void);

#define PGM_TYPE_TEXT_STRETCH pgm_text_stretch_get_type()
GType pgm_text_stretch_get_type (void);

#define PGM_TYPE_TEXT_STYLE pgm_text_style_get_type()
GType pgm_text_style_get_type (void);

#define PGM_TYPE_TEXT_VARIANT pgm_text_variant_get_type()
GType pgm_text_variant_get_type (void);

#define PGM_TYPE_TEXT_WEIGHT pgm_text_weight_get_type()
GType pgm_text_weight_get_type (void);

/* --- ./pgmviewport.h --- */
#define PGM_TYPE_VIEWPORT_CURSOR pgm_viewport_cursor_get_type()
GType pgm_viewport_cursor_get_type (void);

#define PGM_TYPE_VIEWPORT_CAPACITY pgm_viewport_capacity_get_type()
GType pgm_viewport_capacity_get_type (void);

#define PGM_TYPE_VIEWPORT_ROTATION pgm_viewport_rotation_get_type()
GType pgm_viewport_rotation_get_type (void);

#define PGM_TYPE_VIEWPORT_REFLECTION pgm_viewport_reflection_get_type()
GType pgm_viewport_reflection_get_type (void);

/* --- ./pgmlinearalgebra.h --- */
#define PGM_TYPE_MAT4X4_PREDEFINED pgm_mat4x4_predefined_get_type()
GType pgm_mat4x4_predefined_get_type (void);

/* --- ./pgmimagesink.h --- */
#define PGM_TYPE_IMAGE_SINK_EVENT_MASK pgm_image_sink_event_mask_get_type()
GType pgm_image_sink_event_mask_get_type (void);

G_END_DECLS

#endif

/* Generated data ends here */
